Class: DynamicPDFApi::PdfInformation

Inherits:
Object
  • Object
show all
Defined in:
lib/ruby_client/PdfInformation.rb

Overview

Represents the pdf information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize ⇒ PdfInformation

Returns a new instance of PdfInformation.



6
7
8
9
10
11
12
13
14
15
16
17
18
19
# File 'lib/ruby_client/PdfInformation.rb', line 6

def initialize
  @author = nil
  @subject = nil
  @keywords = nil
  @creator = nil
  @producer = nil
  @title = nil
  @pages = {}
  @form_fields = nil
  @custom_properties = nil
  @xmp_meta_data = nil
  @signed = nil
  @tagged = nil
end

Instance Attribute Details

#author ⇒ Object

Gets the author.



24
25
26
# File 'lib/ruby_client/PdfInformation.rb', line 24

def author
  @author
end

#creator ⇒ Object

Gets the creator.



39
40
41
# File 'lib/ruby_client/PdfInformation.rb', line 39

def creator
  @creator
end

#custom_properties ⇒ Object

Gets the custom properties.



64
65
66
# File 'lib/ruby_client/PdfInformation.rb', line 64

def custom_properties
  @custom_properties
end

#form_fields ⇒ Object

Gets the form fields.



59
60
61
# File 'lib/ruby_client/PdfInformation.rb', line 59

def form_fields
  @form_fields
end

#keywords ⇒ Object

Gets the keywords.



34
35
36
# File 'lib/ruby_client/PdfInformation.rb', line 34

def keywords
  @keywords
end

#pages ⇒ Object

Gets the collection of PageInformation.



54
55
56
# File 'lib/ruby_client/PdfInformation.rb', line 54

def pages
  @pages
end

#producer ⇒ Object

Gets the producer.



44
45
46
# File 'lib/ruby_client/PdfInformation.rb', line 44

def producer
  @producer
end

#signed ⇒ Object

Gets the boolean, indicating whether the pdf is signed.



74
75
76
# File 'lib/ruby_client/PdfInformation.rb', line 74

def signed
  @signed
end

#subject ⇒ Object

Gets the subject.



29
30
31
# File 'lib/ruby_client/PdfInformation.rb', line 29

def subject
  @subject
end

#tagged ⇒ Object

Gets the boolean, indicating whether the pdf is tagged.



79
80
81
# File 'lib/ruby_client/PdfInformation.rb', line 79

def tagged
  @tagged
end

#title ⇒ Object

Gets the title.



49
50
51
# File 'lib/ruby_client/PdfInformation.rb', line 49

def title
  @title
end

#xmp_meta_data ⇒ Object

Gets the boolean representing xmp meta data.



69
70
71
# File 'lib/ruby_client/PdfInformation.rb', line 69

def 
  @xmp_meta_data
end